/*
 * Copyright 2013 Canonical Ltd.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * telephony-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1
import Dee 3.0

Page {
    property string stream: "messages"
    property int unseen: 0
    property string search
    property DeeListModel deeModel: _messagesModel

    Behavior on x {
        SequentialAnimation{
            PropertyAction { property: "x"; value: main.width }
            PropertyAnimation { duration: 400 }
        }
    }

    onUnseenChanged: {
        updatesText.text = unseen == 1 ? (unseen + i18n.tr(" new update")) : (unseen + i18n.tr(" new updates"));
    }

    Component {
        id: statusDelegate
        StatusUpdateTile {
            id: content
            width: ListView.view.width
            height: childrenRect.height
            ListView.onAdd: SequentialAnimation {
                ScriptAction { script: {unseen++; console.log(column_0[0][0] + " " + column_0[0][1] + " " + column_0[0][2]) }}
            }
            ThinDivider {}
        }
    }
    
    onStreamChanged: {
        console.log("stream changed to " + stream);
    }

    onSearchChanged: {
        console.log ("onSearchChanged");
    }

    onDeeModelChanged: {
        listView.model = deeModel;
    }

    ListView {
        id: listView
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            right: parent.right
        }
        snapMode: ListView.SnapToItem
        verticalLayoutDirection: ListView.BottomToTop
        cacheBuffer: parent.height * 2

        delegate: statusDelegate
        focus: true

        add: Transition {
            NumberAnimation { properties: "opacity,scale"; from: 0; to: 1.0; duration: 400 }
        }

        displaced: Transition {
            id: dispTrans
            SequentialAnimation {
                PauseAnimation {
                    duration: (dispTrans.ViewTransition.index -
                            dispTrans.ViewTransition.targetIndexes[0]) * 100
                }
                ParallelAnimation {
                    NumberAnimation {
                        property: "x"; to: dispTrans.ViewTransition.item.x + 20
                        easing.type: Easing.OutQuad
                    }
                    NumberAnimation {
                        property: "y"; to: dispTrans.ViewTransition.item.y + 50
                        easing.type: Easing.OutQuad
                    }
                }
                NumberAnimation { properties: "x,y"; duration: 500; easing.type: Easing.OutBounce }
                // ensure opacity and scale values return to 1.0
                NumberAnimation { property: "opacity"; to: 1.0 }
                NumberAnimation { property: "scale"; to: 1.0 }
            }
        }

        populate: Transition {
            ScriptAction { script: waitTimer.start() }
        }

        Item {
            id: updatesBanner
            anchors {
                top: parent.top
                left: parent.left
                right: parent.right
            }
            width: parent.width
            height: 165
            visible: unseen > 0
            Rectangle {
                anchors.centerIn: parent
                color: "lightgray"
                height: updatesText.height + units.gu(2)
                width: parent.width
                Text {
                    id: updatesText
                    anchors {
                        centerIn: parent
                        margins: units.gu(2)
                    }
                    text: ""
                    height: 10
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        unseen = 0;
                        updatesText.text = "";
                        updatesBanner.visible = false;
                        listView.positionViewAtEnd();
                    }
                }
            }
        }
    }

    Timer {
        id: waitTimer
        interval: 500
        repeat: false
        triggeredOnStart: false
        running: false
        onTriggered: { 
            listView.positionViewAtEnd();
        }
    }

    Scrollbar {
        flickableItem: listView
    }

    property ActionList tools: ToolbarActions {
        Action {
            text: i18n.tr("Top")
            onTriggered: {
                listView.positionViewAtEnd()
            }
        }
        Action {
            text: i18n.tr("Post")
            iconSource: ("images/gwibber-new-post.png")
            onTriggered: { 
                tools.active = false;
                post.visible = true;
            }
        }
        back {
            text: i18n.tr("Cancel")
            visible: true
            onTriggered: active = false;
        }
    }
}
